
#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <time.h>
#include <string.h>
#include <unistd.h>

#include "ftdispi.h"

#define MAX_DATA 1600

int main(int argc, char *argv[])
{
  libusb_context *ctx;
  struct ftdispi_s *dev;
  int n, i, j;
  uint8_t idata[MAX_DATA], odata[MAX_DATA];

  srandom(time(NULL));

  assert(!libusb_init(&ctx));
  assert(dev = ftdispi_new(ctx, 0x0403, 0xbca0, 0, 100, 0, NULL));
  assert(!ftdispi_freq(dev, 100000));

  assert(!ftdispi_loop(dev, argc > 1));

  assert(!ftdispi_gpio_conf(dev, FTDI_SPI_GPIOH1, 1, 1));
  assert(ftdispi_gpio_get(dev, FTDI_SPI_GPIOH2) >= 0);

  for(i = 0; i < 10; i++) {
    n = random() % 10 + 1;
    for(j = 0; j < n; j++)
      odata[j] = random() & 0xff;
    memset(idata, 0xaa, MAX_DATA);
    for(j = 0; j < n; j++)
      printf("%02x ", odata[j]);
    assert(!ftdispi_spi(dev, odata, n, idata, n));
    printf("-");
    for(j = 0; j < n; j++)
      printf(" %02x", idata[j]);
    printf("\n");
    if (argc > 1) {
      if (memcmp(odata, idata, n)) {
	printf("data mismatch while loopback!\n");
	assert(0);
      }
    }
  }

  libusb_exit(ctx);
  return 0;
}
